<?php

/**
 * File holding your personalized settings and methods for the
 * Layout Solution
 *
 * <p>Details about using this file can be found in the class level
 * documentation, below.</p>
 *
 * <p>This is part of the Layout Solution.  See the layout.inc file
 * for more information, the license, etc.</p>
 *
 * @package    LayoutSolution
 * @author     Daniel Convissor <danielc@AnalysisAndSolutions.com>
 * @copyright  The Analysis and Solutions Company, 2001-2009
 * @version    $Name: rel-5-12 $ $Id: layout.custom.inc,v 5.5 2009/03/19 15:45:55 danielc Exp $
 * @link       http://www.LayoutSolution.info/
 */

/**
 * Contains your personalized settings and methods for the Layout Solution
 *
 * <p>This class has your Site Layout Information variables.</p>
 *
 * <p>The class also has your Site Contact Information variables.  They
 * allow you to set this stuff once and use throughout your website.  So,
 * if you move, there's only one change to make -- beside getting used to
 * the new office and remembering where the heck you put those papers! :)</p>
 *
 * <p>Finally, here is where you compose commonly used components.  This
 * simplifies page design, allowing you to focus on page specific
 * content.  Also, if you want to implement a site-wide design change,
 * like adding a new button to the navigation bar, all you need to do is
 * edit this file!</p>
 *
 * <p>The layouts we've provided are simple examples of what you can do
 * with this program. Alter them as you see fit.  Add more functions for
 * other page elements you commonly use.</p>
 *
 * @package    LayoutSolution
 * @author     Daniel Convissor <danielc@AnalysisAndSolutions.com>
 * @copyright  The Analysis and Solutions Company, 2001-2009
 * @version    $Name: rel-5-12 $
 * @link       http://www.LayoutSolution.info/
 */
class LayoutSolution_Customizations {

    //     S I T E     L A Y O U T     I N F O R M A T I O N

    /**
     * Name of web site, eg <kbd>www.example.org</kbd>
     *
     * <p>Don't put <kbd>http://</kbd> in front or a slash at the end.</p>
     *
     * @var  string
     */
    var $Host = 'www.example.org';

    /**
     * Name of your development server, eg <kbd>localhost</kbd>
     *
     * <p>Don't put <kbd>http://</kbd> in front or a slash at the end.</p>
     *
     * @var  string
     */
    var $LocalHost = 'localhost';

    /**
     * Development subdirectory
     *
     * <p>This path is added to the <var>$LocalHost</var> URI when using
     * the development server.</p>
     *
     * <p>Place a forward slash in front of the directory name but not on
     * the end, eg <kbd>/foo</kbd>.</p>
     *
     * @var  string
     */
    var $LocalDirAppend = '';

    /**
     * Sub-directory where graphics are stored
     * @var  string
     */
    var $GraphicsDir = 'graphics';

    /**
     * Maximum length allowed for URI's and HTTP_REFERER's submited by viewers
     * @var  string
     */
    var $URIMaxLen = 255;


    //     S I T E     C O N T A C T     I N F O R M A T I O N

    /**
     * Name of your company
     * @var  string
     */
    var $Name = 'Foo Inc.';

    /**
     * Main information/customer service email address
     * @var  string
     */
    var $Email = 'info@example.org';

    /**
     * Street address where mail should go
     * @var  string
     */
    var $Address = '4 Main St';

    /**
     * Municipality of your mailing address
     * @var  string
     */
    var $City = 'Anywhere';

    /**
     * State of your mailing address
     * @var  string
     */
    var $State = 'ZZ';

    /**
     * Zip / postal code
     * @var  string
     */
    var $Zip = '00000';

    /**
     * Country
     *
     * <p>It's best to use your ISO 3166 country code.</p>
     *
     * @var  string
     * @link http://www.iso.org/iso/en/prods-services/iso3166ma/02iso-3166-code-lists/index.html
     */
    var $Country = 'CC';

    /**
     * Main information/customer service phone number
     * @var  string
     */
    var $Phone = '123-456-7890';

    /**
     * Main fax number
     * @var  string
     */
    var $Fax = '123-456-7891';



    /**
     * Stuff you want to appear at the top of each page
     *
     * <p>Sets HTTP headers then includes the layout.head.inc file.</p>
     *
     * <p>The default layout.head.inc requires the <var>short_open_tag</var>
     * php.ini setting to be <kbd>On</kbd>.  If your system has this turned
     * off and you can't get it turned on, rework layout.head.inc so it uses
     * full php tags.</p>
     *
     * <p>layout.head.inc in turn includes the layout.css file.</p>
     *
     * <p>The following variables must be set by you inside each web
     * page.  This method then uses the variables in the <head> section
     * of the HTML output.</p>
     *
     * <p><var>$Title</var>: the page's title.  Used in the <title>
     * and <h1> elements.</p>
     *
     * <p><var>$Description</var>: a summary of the page for use in the
     * description meta tag.</p>
     *
     * <p><var>$Keywords</var>: a comma separated word list that goes
     * into the keyword meta tag.</p>
     *
     * <p><var>$Robots</var>: comma separated directives for search
     * engines.  Goes into a robots meta tag.
     * Values can be one or more of the following: <kbd>noindex</kbd>,
     * <kbd>nofollow</kbd>, and <kbd>noarchive</kbd>.</p>
     *
     * <p><var>$Style</var>: Cascading Style Sheet rule additions for
     * this page.</p>
     *
     * @return void
     * @uses layout.head.inc
     */
    function Head() {
        // Leave this stuff alone unless you know what you're doing.

        global $Title, $Description, $Keywords, $Robots, $Style;
        header('Content-Type: text/html; charset=ISO-8859-1');
        echo '<' . '?xml version="1.0" standalone="no"?' . '>';

        include $this->IncludeDir . '/layout.head.inc';
    }


    /**
     * Stuff you want to appear at the bottom of each page
     *
     * <p>Includes the layout.foot.inc file.</p>
     *
     * <p>The default layout.foot.inc requires the <var>short_open_tag</var>
     * php.ini setting to be <kbd>On</kbd>.  If your system has this turned
     * off and you can't get it turned on, rework layout.foot.inc so it uses
     * full php tags.</p>
     *
     * @return void
     * @uses layout.foot.inc
     */
    function Foot() {
        include $this->IncludeDir . '/layout.foot.inc';
    }
}
